import { Exceptionless, toError } from "@exceptionless/browser";
angular.module("exceptionless", [])
    .constant("$ExceptionlessClient", Exceptionless)
    .factory("exceptionlessHttpInterceptor", ["$location", "$q", "$ExceptionlessClient", ($location, $q, $ExceptionlessClient) => {
        return {
            responseError: function responseError(response) {
                if (response.status === 404) {
                    void $ExceptionlessClient.submitNotFound(response.config.url);
                }
                else if (response.status !== 401) {
                    const message = `[${response.status}] ${(response.data?.Message ?? response.config.url)}`;
                    void $ExceptionlessClient.createUnhandledException(new Error(message), "errorHttpInterceptor")
                        .setSource(response.config.url)
                        .setProperty("response", response)
                        .setProperty("referrer", $location.absUrl())
                        .submit();
                }
                return $q.reject(response);
            }
        };
    }])
    .config(["$httpProvider", "$provide", "$ExceptionlessClient", ($httpProvider, $provide, $ExceptionlessClient) => {
        $httpProvider.interceptors.push("exceptionlessHttpInterceptor");
        $provide.decorator("$exceptionHandler", ["$delegate", ($delegate) => {
                return (exception, cause) => {
                    $delegate(exception, cause);
                    void $ExceptionlessClient.createUnhandledException(exception, "$exceptionHandler").setMessage(cause).submit();
                };
            }]);
        $provide.decorator("$log", ["$delegate", ($delegate) => {
                function decorateRegularCall(property, logLevel) {
                    const previousFn = $delegate[property];
                    return $delegate[property] = (...args) => {
                        if (angular.mock) {
                            $delegate[property].logs = [];
                        }
                        // eslint-disable-next-line prefer-spread
                        previousFn.apply(null, args);
                        if (args[0] && args[0].length > 0) {
                            void $ExceptionlessClient.submitLog(undefined, args[0], logLevel);
                        }
                    };
                }
                $delegate.log = decorateRegularCall("log", "Trace");
                $delegate.info = decorateRegularCall("info", "Info");
                $delegate.warn = decorateRegularCall("warn", "Warn");
                $delegate.debug = decorateRegularCall("debug", "Debug");
                $delegate.error = decorateRegularCall("error", "Error");
                return $delegate;
            }]);
    }])
    .run(["$rootScope", "$ExceptionlessClient", ($rootScope, $ExceptionlessClient) => {
        $rootScope.$on("$routeChangeSuccess", (_event, next, current) => {
            if (!current) {
                return;
            }
            void $ExceptionlessClient.createFeatureUsage(current.name)
                .setProperty("next", next)
                .setProperty("current", current)
                .submit();
        });
        $rootScope.$on("$routeChangeError", (_event, current, previous, rejection) => {
            const error = toError(rejection, "Route Change Error");
            void $ExceptionlessClient.createUnhandledException(error, "$routeChangeError")
                .setProperty("current", current)
                .setProperty("previous", previous)
                .submit();
        });
        $rootScope.$on("$stateChangeSuccess", (_event, toState, toParams, fromState, fromParams) => {
            if (!toState || toState.name === "otherwise") {
                return;
            }
            void $ExceptionlessClient.createFeatureUsage((toState.controller || toState.name))
                .setProperty("toState", toState)
                .setProperty("toParams", toParams)
                .setProperty("fromState", fromState)
                .setProperty("fromParams", fromParams)
                .submit();
        });
        $rootScope.$on("$stateNotFound", (_event, unfoundState, fromState, fromParams) => {
            if (!unfoundState) {
                return;
            }
            void $ExceptionlessClient.createNotFound(unfoundState.to)
                .setProperty("unfoundState", unfoundState)
                .setProperty("fromState", fromState)
                .setProperty("fromParams", fromParams)
                .submit();
        });
        const stateChangeError = "$stateChangeError";
        $rootScope.$on(stateChangeError, (_event, toState, toParams, fromState, fromParams, error) => {
            if (!error) {
                return;
            }
            const builder = error && error.status === 404 ? $ExceptionlessClient.createNotFound(error.config.url) : $ExceptionlessClient.createUnhandledException(error, stateChangeError);
            void builder.setSource(stateChangeError)
                .setMessage(error?.statusText)
                .setProperty("toState", toState)
                .setProperty("toParams", toParams)
                .setProperty("fromState", fromState)
                .setProperty("fromParams", fromParams)
                .submit();
        });
        $rootScope.$on("$destroy", () => {
            void $ExceptionlessClient.config.services.queue.process();
        });
    }]);
//# sourceMappingURL=index.js.map